==> azure_storage_blobs-0.1.0.crate: azure_storage_blobs-0.1.0/src/blob/responses/mod.rs <==
mod delete_blob_response;
pub use self::delete_blob_response::DeleteBlobResponse;
mod release_blob_lease_response;
pub use self::release_blob_lease_response::ReleaseBlobLeaseResponse;
mod change_blob_lease_response;
pub use self::change_blob_lease_response::ChangeBlobLeaseResponse;
mod renew_blob_lease_response;
pub use self::renew_blob_lease_response::RenewBlobLeaseResponse;
mod acquire_blob_lease_response;
pub use self::acquire_blob_lease_response::AcquireBlobLeaseResponse;
mod get_block_list_response;
pub use self::get_block_list_response::GetBlockListResponse;
mod put_block_list_response;
pub use self::put_block_list_response::PutBlockListResponse;
mod put_block_response;
pub use self::put_block_response::PutBlockResponse;
mod clear_page_response;
pub use self::clear_page_response::ClearPageResponse;
mod put_block_blob_response;
pub use self::put_block_blob_response::PutBlockBlobResponse;
mod list_blobs_response;
pub use self::list_blobs_response::ListBlobsResponse;
mod get_blob_response;
pub use self::get_blob_response::GetBlobResponse;
mod get_blob_properties_response;
pub use self::get_blob_properties_response::GetBlobPropertiesResponse;
mod put_blob_response;
pub use self::put_blob_response::PutBlobResponse;
mod update_page_response;
pub use self::update_page_response::UpdatePageResponse;
mod break_blob_lease_response;
pub use self::break_blob_lease_response::BreakBlobLeaseResponse;
mod copy_blob_from_url_response;
pub use copy_blob_from_url_response::CopyBlobFromUrlResponse;
mod copy_blob_response;
pub use copy_blob_response::CopyBlobResponse;
mod get_blob_metadata_response;
pub use get_blob_metadata_response::GetBlobMetadataResponse;
mod set_blob_metadata_response;
pub use set_blob_metadata_response::SetBlobMetadataResponse;

==> azure_storage_blobs-0.2.0.crate: azure_storage_blobs-0.2.0/src/blob/responses/mod.rs <==
mod delete_blob_response;
pub use self::delete_blob_response::DeleteBlobResponse;
mod release_blob_lease_response;
pub use self::release_blob_lease_response::ReleaseBlobLeaseResponse;
mod change_blob_lease_response;
pub use self::change_blob_lease_response::ChangeBlobLeaseResponse;
mod renew_blob_lease_response;
pub use self::renew_blob_lease_response::RenewBlobLeaseResponse;
mod acquire_blob_lease_response;
pub use self::acquire_blob_lease_response::AcquireBlobLeaseResponse;
mod get_block_list_response;
pub use self::get_block_list_response::GetBlockListResponse;
mod put_block_list_response;
pub use self::put_block_list_response::PutBlockListResponse;
mod put_block_response;
pub use self::put_block_response::PutBlockResponse;
mod clear_page_response;
pub use self::clear_page_response::ClearPageResponse;
mod put_block_blob_response;
pub use self::put_block_blob_response::PutBlockBlobResponse;
mod list_blobs_response;
pub use self::list_blobs_response::ListBlobsResponse;
mod get_blob_response;
pub use self::get_blob_response::GetBlobResponse;
mod get_blob_properties_response;
pub use self::get_blob_properties_response::GetBlobPropertiesResponse;
mod put_blob_response;
pub use self::put_blob_response::PutBlobResponse;
mod update_page_response;
pub use self::update_page_response::UpdatePageResponse;
mod break_blob_lease_response;
pub use self::break_blob_lease_response::BreakBlobLeaseResponse;
mod copy_blob_from_url_response;
pub use copy_blob_from_url_response::CopyBlobFromUrlResponse;
mod copy_blob_response;
pub use copy_blob_response::CopyBlobResponse;
mod get_blob_metadata_response;
pub use get_blob_metadata_response::GetBlobMetadataResponse;
mod set_blob_metadata_response;
pub use set_blob_metadata_response::SetBlobMetadataResponse;
mod set_blob_tier_response;
pub use set_blob_tier_response::SetBlobTierResponse;
mod get_page_ranges_response;
pub use get_page_ranges_response::GetPageRangesResponse;
